#
# Makefile Template for Tessy
# Compiler: Cosmic STM8
# Debugger: ST Microelectronics STVD
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CODE_SEGMENT_BEGIN    :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# DATA_SEGMENT_BEGIN    :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# STACK_POINTER_INIT    :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=
# VECTOR_TABLE_BEGIN    :=
# VECTOR_TABLE_FILE     :=
# ZERO_PAGE_BEGIN       :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-d
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-i
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS		:=	$(shell ts_pathname -s $(TESSY_SYS))
COSMIC_HOME			:= $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
MODULE_PATH_DOS	:= $(shell ts_pathname -w '$(MODULE_PATH)')

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.elf

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_stvd7_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_stvd7_cosmic_stm8.mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := -no +modsl +debug -co$(MODULE_PATH_DOS) -l -dTESSY -dTS_SLAVE -dTS_STVD7 -dTS_ST7 -dTS_HAVE_FLOAT
S_LINK_OPTIONS := -m "$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.map"
S_INCLUDES     := -i$(TESSY_SYS_DOS)\include\tessy\comm -i$(MODULE_PATH_DOS)
S_CC           := $(COSMIC_HOME)\cxstm8.exe
S_LINK         := $(COSMIC_HOME)\clnk.exe
S_OBJECTS      := $(MODULE_PATH_DOS)\tslows_stvd7.o \
                  $(MODULE_PATH_DOS)\tstcomm.o \
                  $(MODULE_PATH_DOS)\tscoml.o
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.o
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.o



#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) $<


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.stm8 : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_OBJECTS) \
															$(MODULE_PATH_DOS)\vector_cosmic_stm8.o

	@echo *
	@echo ***** Linking Slave *****
	@echo +seg .text -b$(CODE_SEGMENT_BEGIN) -n .text > $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .const -a .text -n .const >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .bsct -b$(ZERO_PAGE_BEGIN) -n .bsct >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .ubsct -a .bsct -n .ubsct >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .share -a .ubsct -is >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .data -b$(DATA_SEGMENT_BEGIN) -n .data >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .bss -a .data >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@sh -c 'for f in $(S_SRC_OBJECTS); do echo "$$f" >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf; done'
	@echo $(S_UC_OBJECT) >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(S_STUB_OBJECT) >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .TESSY_CODE -b0x1000 -n .TESSY_CODE >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .TESSY_DATA -a .TESSY_CODE -n .TESSY_DATA >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .TESSY_DATA2 -a .TESSY_DATA -n .TESSY_DATA2 >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.o >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@sh -c 'for f in $(S_OBJECTS); do echo "$$f" >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf; done'
	@echo $(USER_LINK_OPTIONS) #USER_LINK_OPTIONS  >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(COSMIC_HOME)\lib\crtsi.sm8 >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(COSMIC_HOME)\lib\libisl.sm8 >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(COSMIC_HOME)\lib\libm.sm8 >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +seg .vector -b $(VECTOR_TABLE_BEGIN) -m 0x80 >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo $(MODULE_PATH_DOS)\vector_cosmic_stm8.o >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +def __endzp=@.ubsct >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +def __memory=@.bss >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf
	@echo +def __stack=$(STACK_POINTER_INIT) >> $(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf

	$(S_LINK) -o "$@" $(S_LINK_OPTIONS) \
				"$(MODULE_PATH_DOS)\ts_$(TESTOBJECT).lkf"
	@-ts_rm "$(MODULE_PATH)"/*.o


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.elf : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.stm8
	$(COSMIC_HOME)\cvdwarf $<
	@ts_cp "$@" "$(MODULE_PATH_DOS)\ts_slave.elf"

#####################################################################
#END_TARGETS
#####################################################################

